@@ -40,7 +40,12 @@ plot.mm.s <- function(s, whichcells=NULL,
   ## If FOR.FIGURE is true, we make a slightly different outline, which
   ## is useful for making the figures.
 
-  whichcells = names.to.indexes(names(s$spikes), whichcells, allow.na=TRUE)
+  if (length(whichcells)>0 && is.numeric(whichcells[1])) {
+    ## leave whichcells alone.
+    ;
+  } else {
+    whichcells = names.to.indexes(names(s$spikes), whichcells, allow.na=TRUE)
+  }
 
 
   if (is.null(main)) {
@@ -123,7 +128,9 @@ plot.mm.s <- function(s, whichcells=NULL,
     } else {
       labels <- whichcells
     }
-    mtext(labels, side=2, at=allys, las=1)
+    ##mtext(labels, side=2, at=allys, las=1)
+    ## Try to draw as axis, but still they overlap...
+    axis(2, at=allys, labels=labels, las=1, tick=F)
   }
 
   if (missing(show.episodes)) {
@@ -229,21 +236,23 @@ read.spikes <- function(reader, ...) {
 
 
 
-make.jay.layout <- function(positions) {
+make.jay.layout <- function(names) {
   ## make the layout for Jay's MEA
 
 
-  xlim <- ylim <- c(50, 850)
+  positions <- substring(names, 4,5)
+  xlim <- ylim <- c(50, 850)            #now in arrays.R
   spacing <- 100
 
   cols <- as.integer(substring(positions, 1,1)) * spacing
   rows <- as.integer(substring(positions, 2,2)) * spacing
   pos <- cbind(cols, rows)
   
-  rownames(pos) <- positions
+  rownames(pos) <- names
+  array <- 'MCS_8x8_100um'
   
   layout <- list(xlim=xlim, ylim=ylim, spacing=spacing,
-                 pos=pos)
+                 pos=pos, array=array)
 
   class(layout) <- "mealayout"
 
@@ -341,11 +350,11 @@ jay.read.spikes <- function(filename, ids=NULL,
 
   ## meanfiring rate is the number of spikes divided by the (time of
   ## last spike - time of first spike).  
-  meanfiringrate <- nspikes/ ( sapply(spikes, max) - sapply(spikes, min))
+  meanfiringrate <- nspikes/ (end - beg)
 
   ## Parse the channel names to get the cell positions.
 
-  layout <- make.jay.layout( substring(channels, 4, 5))
+  layout <- make.jay.layout(channels)
   
   ## temporary test: shuffle electrode positions.
   ## pos <- pos[sample(1:num.channels),]
@@ -391,9 +400,9 @@ jay.read.spikes <- function(filename, ids=NULL,
               file=filename,
               layout=layout,
               rates=rates,
-              rec.time=rec.time,
-              unit.offsets=unit.offsets
-              ## TODO: how to return arguments, expanding all vars?
+              unit.offsets=unit.offsets,
+              rec.time=rec.time
+               ## TODO: how to return arguments, expanding all vars?
               ##call=match.call()
               )
   class(res) <- "mm.s"
